@@ -1,6 +1,7 @@
-import traceback, json
+import traceback, json, sys, executing
 
 from functools  import wraps
+from textwrap   import dedent
 from shutil     import rmtree
 from typing     import Any, Optional
 from time   import perf_counter
@@ -112,11 +113,11 @@ _func_timer = FunctionTimer()._func_timer
 func_timer = FunctionTimer()
 
 
-def try_traceback(skip_traceback=False):
+def try_traceback(print_traceback=False):
     """Decorator to catch and handle exceptions raised by a function.
     
     Parameters:
-    - `skip_traceback` (bool): Whether to skip printing the traceback information.
+    - `print_traceback` (bool): Whether to skip printing the traceback information.
     
     Returns:
     - `function`: The decorated function.
@@ -128,7 +129,7 @@ def try_traceback(skip_traceback=False):
             try:
                 return func(*args, **kwargs)
             except:
-                if not skip_traceback:
+                if print_traceback:
                     fprint(traceback.format_exc())
                 return None
         return wrapper
@@ -220,6 +221,62 @@ def enter_to_continue(text:str='', nl:bool=True, use_suffix:bool=True) -> bool:
     return not any(inpt)
 
 
+def fprint_array(arr, header:str='', indx_brackets:str='[]', start_num:int=0, nl:bool=True) -> None:
+    """This function prints the elements of an array along with their index numbers.
+
+    Parameters:
+    - `arr` (`list`|`set`|`tuple`|`dict`): The input array whose elements are to be printed.
+    - `header` (str): Header message to be printed before the array elements. Default is ''.
+    - `indx_brackets` (str): Type of brackets to be used for index numbers. Default is '`[]`'.
+    - `start_num` (int): Starting index number for printing elements. Default is 0.
+    - `nl` (bool): Whether to append a newline character after the input.
+    
+    Returns:
+    - `None`
+    """
+
+    def _get_array_name() -> str:
+        class Source(executing.Source):
+            def get_text_with_indentation(self, node):
+                result = self.asttokens().get_text(node)
+                if '\n' in result:
+                    result = ' ' * node.first_token.start[1] + result
+                    result = dedent(result)
+                result = result.strip()
+                return result
+        
+        callFrame = sys._getframe(2)
+        callNode = Source.executing(callFrame).node
+        source = Source.for_frame(callFrame)
+        inpt_array_name = source.get_text_with_indentation(callNode.args[0])
+
+        return inpt_array_name
+
+    config_indx_num = lambda indx : f'{indx_brackets[0]}{indx}{indx_brackets[1]}'
+
+    arr_type = arr.__class__.__name__
+    
+    if arr_type not in 'list set tuple dict'.split():
+        arr_name = _get_array_name()
+        print(f'Given array ({arr_name}) is not a valid format: {arr_type}')
+        return
+
+    if header:
+        print(header)
+
+    match arr_type:
+        case 'list' | 'set' | 'tuple':
+            for indx, value in enumerate(arr, start=start_num):
+                print(f'{config_indx_num(indx)} {value}')
+
+        case 'dict':
+            for indx, (key, value) in enumerate(arr.items(), start=start_num):
+                print(f'{config_indx_num(indx)} {key}: {value}')
+
+    if nl:
+        print()
+
+
 def choose_from_list(_array:Any, header_text:str='', header_nl:bool=False, input_text:str='Input index: ', choose_total:int=1, start_num:int=0, choose_until_correct:bool=True) -> list:
     """Prompt the user to choose one or more values from a list.
     
@@ -419,7 +476,7 @@ def create_full_dir_path(dir_path:str, force:bool=False, do_print:bool=True) ->
     return was_created
 
 
-@try_traceback(skip_traceback=True)
+@try_traceback(print_traceback=True)
 def remove_file_dir(do:str, do_path:str, force:bool=False, do_print:bool=True) -> bool:
     """Remove a file or directory at the specified path.
     
